/*
 * Copyright (C) 2017 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.dsl.api;

import com.intellij.openapi.project.Project;
import com.intellij.openapi.vfs.VirtualFile;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.io.File;
import java.util.List;

public interface GradleSettingsModel extends GradleFileModel {
  @Nullable
  static GradleSettingsModel get(@NotNull Project project) {
    return GradleModelProvider.get().getSettingsModel(project);
  }

  @NotNull
  static GradleSettingsModel get(@NotNull VirtualFile file,
                                 @NotNull Project project,
                                 @NotNull String moduleName) {
    return GradleModelProvider.get().getSettingsModel(file, project, moduleName);
  }

  @NotNull
  List<String> modulePaths();

  @NotNull
  GradleSettingsModel addModulePath(@NotNull String modulePath);

  @NotNull
  GradleSettingsModel removeModulePath(@NotNull String modulePath);

  @NotNull
  GradleSettingsModel replaceModulePath(@NotNull String oldModulePath, @NotNull String newModulePath);

  @Nullable
  File moduleDirectory(String modulePath);

  @Nullable
  String moduleWithDirectory(@NotNull File moduleDir);

  @Nullable
  GradleBuildModel moduleModel(@NotNull String modulePath);

  @Nullable
  String parentModule(@NotNull String modulePath);

  @Nullable
  GradleBuildModel getParentModuleModel(@NotNull String modulePath);

  @Nullable
  File buildFile(@NotNull String modulePath);
}
