/*
 * Copyright (C) 2015 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.editor.value;

import com.google.common.base.Function;
import com.google.common.collect.*;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.List;

public class SdkValueManager extends IntegerValueManager {

  private static final List<String> ourHardCodedValues = Lists.reverse(Lists.newArrayList(
    Iterables.transform(ContiguousSet.create(Range.closed(1, 21), DiscreteDomain.integers()), new Function<Integer, String>() {
      @Override
      public String apply(Integer input) {
        return String.valueOf(input);
      }
    })));

  @Nullable
  @Override
  public String validate(@NotNull String newValue, boolean strict) {
    String problem = super.validate(newValue, strict);
    if (problem != null) {
      return problem;
    }
    // TODO den validate against available versions
    return null;
  }

  @Override
  public boolean isAvailableVersionsHintReady() {
    // TODO den implement
    return true;
  }

  @Nullable
  @Override
  public List<String> hintAvailableVersions() {
    // TODO den check online
    return ourHardCodedValues;
  }
}
