/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.structure.daemon.analysis;

import com.android.tools.idea.gradle.structure.model.PsIssueCollection;
import com.android.tools.idea.gradle.structure.model.PsModel;
import org.jetbrains.annotations.NotNull;

public abstract class PsModelAnalyzer<T extends PsModel> {
  public final void analyze(@NotNull PsModel model, @NotNull PsIssueCollection issueCollection) {
    assert getSupportedModelType().isInstance(model);
    doAnalyze(getSupportedModelType().cast(model), issueCollection);
  }

  protected abstract void doAnalyze(@NotNull T model, @NotNull PsIssueCollection issueCollection);

  @NotNull
  public abstract Class<T> getSupportedModelType();
}
