/*
 * Copyright (C) 2017 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.npw.assetstudio;

import com.android.annotations.NonNull;
import com.android.annotations.Nullable;

import java.nio.file.Path;

/**
 * Common abstraction for images and resource definition generated by
 * {@link IconGenerator#generateIcons(GraphicGeneratorContext, IconGenerator.Options, String)}.
 */
public abstract class GeneratedIcon {
  /** The icon category, see {@link IconCategory}. */
  @NonNull
  public abstract IconCategory getCategory();

  /**
   * The icon name, never null or empty. The meaning of the name depends on the category. For
   * example, the name {@link IconCategory#PREVIEW} is a {@link LauncherIconGenerator.PreviewShape#id}.
   */
  @NonNull
  public abstract String getName();

  /**
   * The relative path of the icon in the resource folder (e.g. res/mipmap-xdpi/foo.png).
   * May be null for icons that don't need to be generated on disk (e.g. a preview icon).
   */
  @Nullable
  public abstract Path getOutputPath();
}
