/*
 * Copyright (C) 2015 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.templates;

import com.google.common.base.Joiner;
import org.jetbrains.annotations.NotNull;

import java.util.Collection;

/**
 * Indicates that parameters have circular dependency and cannot be evaluated.
 */
public final class CircularParameterDependencyException extends Exception {
  /**
   * @param parameterIds IDs of parameters that caused the exception.
   */
  public CircularParameterDependencyException(@NotNull Collection<String> parameterIds) {
    super(String.format("Cyclical parameter dependency found: %s", Joiner.on(", ").join(parameterIds)));
  }
}
