/*
 * Copyright 2000-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.intellij.conversion;

import com.intellij.openapi.components.ServiceManager;
import com.intellij.openapi.project.Project;
import org.jetbrains.annotations.NotNull;

import java.io.File;

/**
 * @author nik
 */
public abstract class ConversionService {

  @NotNull
  public static ConversionService getInstance() {
    ConversionService service = ServiceManager.getService(ConversionService.class);
    return service == null ? new DummyConversionService() : service;
  }

  @NotNull
  public abstract ConversionResult convertSilently(@NotNull String projectPath);

  @NotNull
  public abstract ConversionResult convertSilently(@NotNull String projectPath, @NotNull ConversionListener conversionListener);

  @NotNull
  public abstract ConversionResult convert(@NotNull String projectPath);

  @NotNull
  public abstract ConversionResult convertModule(@NotNull Project project, @NotNull File moduleFile);

  public abstract void saveConversionResult(@NotNull String projectPath);
}
