/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.debugger.engine.evaluation.expression;

import com.intellij.debugger.DebuggerBundle;
import com.intellij.debugger.engine.evaluation.EvaluateException;
import com.intellij.debugger.engine.evaluation.EvaluationContextImpl;
import com.sun.jdi.ObjectReference;
import org.jetbrains.annotations.NotNull;

/**
 * @author egor
 */
public class ThrowEvaluator implements Evaluator {
  @NotNull private final Evaluator myExceptionEvaluator;

  public ThrowEvaluator(@NotNull Evaluator exceptionEvaluator) {
    myExceptionEvaluator = exceptionEvaluator;
  }

  @Override
  public Object evaluate(EvaluationContextImpl context) throws EvaluateException {
    ObjectReference exception = (ObjectReference)myExceptionEvaluator.evaluate(context);
    EvaluateException ex = new EvaluateException(
      DebuggerBundle.message("evaluation.error.method.exception", exception.referenceType().name()));
    ex.setTargetException(exception);
    throw ex;
  }
}
