/*
 * Copyright 2000-2012 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.editor.actions;

import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.editor.Editor;
import com.intellij.openapi.editor.actionSystem.EditorActionHandler;
import org.jetbrains.annotations.NotNull;

/**
 * Moves editor viewport one visual line down. Caret is also moved one line down if it becomes off-screen
 * 
 * @author Denis Zhdanov
 * @since 1/13/12 1:22 PM
 */
public class ScrollDownAndMoveAction extends InactiveEditorAction {
  
  public ScrollDownAndMoveAction() {
    super(new Handler());
  }

  private static class Handler extends EditorActionHandler {
    @Override
    public void execute(@NotNull Editor editor, DataContext dataContext) {
      EditorActionUtil.scrollRelatively(editor, 1, 0, true);
    }
  }
}
