/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.progress

import com.intellij.openapi.project.Project
import org.jetbrains.annotations.Nls

inline fun runModalTask(@Nls(capitalization = Nls.Capitalization.Title) title: String,
                        project: Project? = null,
                        cancellable: Boolean = true,
                        crossinline task: (indicator: ProgressIndicator) -> Unit) {
  ProgressManager.getInstance().run(object : Task.Modal(project, title, cancellable) {
    override fun run(indicator: ProgressIndicator) {
      task(indicator)
    }
  })
}

inline fun runBackgroundableTask(@Nls(capitalization = Nls.Capitalization.Title) title: String,
                                 project: Project? = null,
                                 cancellable: Boolean = true,
                                 crossinline task: (indicator: ProgressIndicator) -> Unit) {
  ProgressManager.getInstance().run(object : Task.Backgroundable(project, title, cancellable) {
    override fun run(indicator: ProgressIndicator) {
      task(indicator)
    }
  })
}