/*
 * Copyright 2000-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.roots.ui.configuration.projectRoot;

import com.intellij.openapi.ui.NamedConfigurable;
import org.jetbrains.annotations.NotNull;

import java.util.Collection;

/**
 * @author nik
 */
public abstract class RemoveConfigurableHandler<T> {
  private final Class<? extends NamedConfigurable<T>> myConfigurableClass;

  public RemoveConfigurableHandler(Class<? extends NamedConfigurable<T>> configurableClass) {
    myConfigurableClass = configurableClass;
  }

  public Class<? extends NamedConfigurable<T>> getConfigurableClass() {
    return myConfigurableClass;
  }

  public boolean canBeRemoved(@NotNull Collection<? extends T> objects) {
    return true;
  }

  public abstract boolean remove(@NotNull Collection<? extends T> objects);
}
