/*
 * Copyright 2000-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.util.registry.ui;

import com.intellij.openapi.ui.CheckBoxWithDescription;
import com.intellij.openapi.util.registry.RegistryValue;
import org.jetbrains.annotations.Nullable;

import javax.swing.*;

public class RegistryCheckBox extends CheckBoxWithDescription {
  private final RegistryValue myValue;

  public RegistryCheckBox(RegistryValue value) {
    this(value, value.getDescription(), null);
  }

  public RegistryCheckBox(RegistryValue value, String text, @Nullable String longDescription) {
    super(new JCheckBox(text), longDescription);

    myValue = value;
    getCheckBox().setSelected(myValue.asBoolean());
  }

  public boolean isChanged() {
    return getCheckBox().isSelected() != myValue.asBoolean();
  }

  public void save() {
    myValue.setValue(Boolean.valueOf(getCheckBox().isSelected()).toString());
  }
}