/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.vcs.log.data.index;

import com.intellij.util.containers.ContainerUtil;
import com.intellij.util.io.DataExternalizer;
import com.intellij.util.io.DataInputOutputUtil;
import org.jetbrains.annotations.NotNull;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.List;

class IntListDataExternalizer implements DataExternalizer<List<Integer>> {
  @Override
  public void save(@NotNull DataOutput out, List<Integer> value) throws IOException {
    DataInputOutputUtil.writeINT(out, value.size());
    for (Integer i : value) {
      out.writeInt(i);
    }
  }

  @Override
  public List<Integer> read(@NotNull DataInput in) throws IOException {
    List<Integer> value = ContainerUtil.newSmartList();

    int size = DataInputOutputUtil.readINT(in);
    for (int i = 0; i < size; i++) {
      value.add(in.readInt());
    }

    return value;
  }
}
