// Copyright 2000-2018 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package org.jetbrains.idea.devkit.completion;

import com.google.common.collect.Sets;
import org.jetbrains.annotations.ApiStatus;

import java.util.Set;

@ApiStatus.Experimental
public final class UiDefaultsHardcodedKeys { //TODO move
  public static final Set<String> UI_DEFAULTS_KEYS = Sets.newHashSet(
    "AATextInfoPropertyKey",
    "AbstractButton.click.textAndMnemonic",
    "AbstractDocument.addition.textAndMnemonic",
    "AbstractDocument.deletion.textAndMnemonic",
    "AbstractDocument.redo.textAndMnemonic",
    "AbstractDocument.styleChange.textAndMnemonic",
    "AbstractDocument.undo.textAndMnemonic",
    "AbstractUndoableEdit.redo.textAndMnemonic",
    "AbstractUndoableEdit.undo.textAndMnemonic",
    "ActionButton.hoverBackground",
    "ActionButton.hoverBorderColor",
    "ActionButton.pressedBackground",
    "ActionButton.pressedBorderColor",
    "AuditoryCues.allAuditoryCues",
    "AuditoryCues.cueList",
    "AuditoryCues.defaultCueList",
    "AuditoryCues.noAuditoryCues",
    "Balloon.error.textInsets",
    "Border.width",
    "Button.actionMap",
    "Button.arc",
    "Button.background",
    "Button.background.opaque",
    "Button.border",
    "Button.darcula.defaultEndColor",
    "Button.darcula.defaultFocusedOutlineColor",
    "Button.darcula.defaultOutlineColor",
    "Button.darcula.defaultShadowColor",
    "Button.darcula.defaultStartColor",
    "Button.darcula.disabledOutlineColor",
    "Button.darcula.disabledText.shadow",
    "Button.darcula.endColor",
    "Button.darcula.focusedOutlineColor",
    "Button.darcula.outlineColor",
    "Button.darcula.outlineDefaultEndColor",
    "Button.darcula.outlineDefaultStartColor",
    "Button.darcula.outlineEndColor",
    "Button.darcula.outlineStartColor",
    "Button.darcula.paintShadow",
    "Button.darcula.selectedButtonForeground",
    "Button.darcula.shadowColor",
    "Button.darcula.shadowWidth",
    "Button.darcula.smallComboButtonBackground",
    "Button.darcula.startColor",
    "Button.darkShadow",
    "Button.defaultButtonFollowsFocus",
    "Button.disabledText",
    "Button.disabledToolBarBorderBackground",
    "Button.focus",
    "Button.focusInputMap",
    "Button.font",
    "Button.foreground",
    "Button.gradient",
    "Button.highlight",
    "Button.intellij.native.borderColor",
    "Button.intellij.native.focusDottedRingColor",
    "Button.intellij.native.focusedBackgroundColor",
    "Button.intellij.native.focusedBorderColor",
    "Button.intellij.native.pressedBackgroundColor",
    "Button.intellij.native.pressedBorderColor",
    "Button.light",
    "Button.margin",
    "Button.opaque",
    "Button.rollover",
    "Button.rolloverIconType",
    "Button.select",
    "Button.shadow",
    "Button.textIconGap",
    "Button.textShiftOffset",
    "Button.toolBarBorderBackground",
    "ButtonUI",
    "CellEditor.border.width",
    "CheckBox.background",
    "CheckBox.border",
    "CheckBox.borderInsets",
    "CheckBox.disabledText",
    "CheckBox.focus",
    "CheckBox.focusInputMap",
    "CheckBox.font",
    "CheckBox.foreground",
    "CheckBox.gradient",
    "CheckBox.icon",
    "CheckBox.margin",
    "CheckBox.rollover",
    "CheckBox.select",
    "CheckBox.textIconGap",
    "CheckBox.textShiftOffset",
    "CheckBox.totalInsets",
    "CheckBoxMenuItem.acceleratorDelimiter",
    "CheckBoxMenuItem.acceleratorFont",
    "CheckBoxMenuItem.acceleratorForeground",
    "CheckBoxMenuItem.acceleratorSelectionForeground",
    "CheckBoxMenuItem.arrowIcon",
    "CheckBoxMenuItem.background",
    "CheckBoxMenuItem.border",
    "CheckBoxMenuItem.borderPainted",
    "CheckBoxMenuItem.checkIcon",
    "CheckBoxMenuItem.commandSound",
    "CheckBoxMenuItem.dashIcon",
    "CheckBoxMenuItem.disabledBackground",
    "CheckBoxMenuItem.disabledForeground",
    "CheckBoxMenuItem.font",
    "CheckBoxMenuItem.foreground",
    "CheckBoxMenuItem.gradient",
    "CheckBoxMenuItem.margin",
    "CheckBoxMenuItem.selectionBackground",
    "CheckBoxMenuItem.selectionForeground",
    "CheckBoxMenuItemUI",
    "CheckBoxUI",
    "Checkbox.select",
    "ColorChooser.background",
    "ColorChooser.cancel.textAndMnemonic",
    "ColorChooser.font",
    "ColorChooser.foreground",
    "ColorChooser.hsb.textAndMnemonic",
    "ColorChooser.hsbBlue.textAndMnemonic",
    "ColorChooser.hsbBrightness.textAndMnemonic",
    "ColorChooser.hsbGreen.textAndMnemonic",
    "ColorChooser.hsbHue.textAndMnemonic",
    "ColorChooser.hsbRed.textAndMnemonic",
    "ColorChooser.hsbSaturation.textAndMnemonic",
    "ColorChooser.ok.textAndMnemonic",
    "ColorChooser.preview.textAndMnemonic",
    "ColorChooser.reset.textAndMnemonic",
    "ColorChooser.rgb.textAndMnemonic",
    "ColorChooser.rgbBlue.textAndMnemonic",
    "ColorChooser.rgbGreen.textAndMnemonic",
    "ColorChooser.rgbRed.textAndMnemonic",
    "ColorChooser.sample.textAndMnemonic",
    "ColorChooser.swatches.textAndMnemonic",
    "ColorChooser.swatchesDefaultRecentColor",
    "ColorChooser.swatchesRecent.textAndMnemonic",
    "ColorChooser.swatchesRecentSwatchSize",
    "ColorChooser.swatchesSwatchSize",
    "ColorChooserUI",
    "ComboBox.actionMap",
    "ComboBox.ancestorInputMap",
    "ComboBox.background",
    "ComboBox.border",
    "ComboBox.buttonBackground",
    "ComboBox.buttonDarkShadow",
    "ComboBox.buttonHighlight",
    "ComboBox.buttonShadow",
    "ComboBox.darcula.arrowButtonBackground",
    "ComboBox.darcula.arrowButtonDisabledForeground",
    "ComboBox.darcula.arrowButtonForeground",
    "ComboBox.darcula.editable.arrowButtonBackground",
    "ComboBox.darcula.nonEditableBackground",
    "ComboBox.disabledBackground",
    "ComboBox.disabledForeground",
    "ComboBox.font",
    "ComboBox.foreground",
    "ComboBox.isEnterSelectablePopup",
    "ComboBox.noActionOnKeyNavigation",
    "ComboBox.padding",
    "ComboBox.selectionBackground",
    "ComboBox.selectionForeground",
    "ComboBox.timeFactor",
    "ComboBox.togglePopup.textAndMnemonic",
    "ComboBoxUI",
    "Component.arc",
    "Desktop.ancestorInputMap",
    "Desktop.background",
    "Desktop.minOnScreenInsets",
    "DesktopIcon.background",
    "DesktopIcon.border",
    "DesktopIcon.borderColor",
    "DesktopIcon.borderRimColor",
    "DesktopIcon.font",
    "DesktopIcon.foreground",
    "DesktopIcon.labelBackground",
    "DesktopIcon.width",
    "DesktopIconUI",
    "DesktopPaneUI",
    "DialogWrapper.southPanelBackground",
    "DialogWrapper.southPanelDivider",
    "DragAndDrop.backgroundBorderColor",
    "DragAndDrop.backgroundColor",
    "DragAndDrop.foregroundColor",
    "EditorPane.background",
    "EditorPane.border",
    "EditorPane.caretBlinkRate",
    "EditorPane.caretForeground",
    "EditorPane.focusInputMap",
    "EditorPane.font",
    "EditorPane.foreground",
    "EditorPane.inactiveBackground",
    "EditorPane.inactiveForeground",
    "EditorPane.margin",
    "EditorPane.selectionBackground",
    "EditorPane.selectionForeground",
    "EditorPaneUI",
    "FileChooser.acceptAllFileFilter.textAndMnemonic",
    "FileChooser.ancestorInputMap",
    "FileChooser.by.textAndMnemonic",
    "FileChooser.byDate.textAndMnemonic",
    "FileChooser.cancelButton.textAndMnemonic",
    "FileChooser.cancelButtonMnemonic",
    "FileChooser.chooseButton.textAndMnemonic",
    "FileChooser.createButton.textAndMnemonic",
    "FileChooser.desktopName",
    "FileChooser.detailsViewActionLabelText",
    "FileChooser.detailsViewIcon",
    "FileChooser.directoryDescription.textAndMnemonic",
    "FileChooser.directoryOpenButton.textAndMnemonic",
    "FileChooser.directoryOpenButtonMnemonic",
    "FileChooser.fileDescription.textAndMnemonic",
    "FileChooser.fileNameLabel.textAndMnemonic",
    "FileChooser.fileNameLabelMnemonic",
    "FileChooser.fileSizeGigaBytes",
    "FileChooser.fileSizeKiloBytes",
    "FileChooser.fileSizeMegaBytes",
    "FileChooser.filesOfTypeLabel.textAndMnemonic",
    "FileChooser.filesOfTypeLabelMnemonic",
    "FileChooser.helpButton.textAndMnemonic",
    "FileChooser.helpButtonMnemonic",
    "FileChooser.homeFolderIcon",
    "FileChooser.listViewActionLabelText",
    "FileChooser.listViewIcon",
    "FileChooser.lookInLabelMnemonic",
    "FileChooser.mac.newFolder",
    "FileChooser.mac.newFolder.subsequent",
    "FileChooser.newFolderAccessibleName",
    "FileChooser.newFolderActionLabelText",
    "FileChooser.newFolderButton.textAndMnemonic",
    "FileChooser.newFolderError.textAndMnemonic",
    "FileChooser.newFolderErrorSeparator",
    "FileChooser.newFolderExistsError.textAndMnemonic",
    "FileChooser.newFolderIcon",
    "FileChooser.newFolderPrompt.textAndMnemonic",
    "FileChooser.newFolderTitle.textAndMnemonic",
    "FileChooser.openButton.textAndMnemonic",
    "FileChooser.openButtonMnemonic",
    "FileChooser.openDialogTitle.textAndMnemonic",
    "FileChooser.openTitle.textAndMnemonic",
    "FileChooser.readOnly",
    "FileChooser.refreshActionLabelText",
    "FileChooser.saveButton.textAndMnemonic",
    "FileChooser.saveButtonMnemonic",
    "FileChooser.saveDialogFileNameLabel.textAndMnemonic",
    "FileChooser.saveDialogTitle.textAndMnemonic",
    "FileChooser.saveTitle.textAndMnemonic",
    "FileChooser.untitledFileName",
    "FileChooser.untitledFolderName",
    "FileChooser.upFolderIcon",
    "FileChooser.updateButton.textAndMnemonic",
    "FileChooser.updateButtonMnemonic",
    "FileChooser.useSystemExtensionHiding",
    "FileChooser.usesSingleFilePane",
    "FileChooser.viewMenuLabelText",
    "FileChooserUI",
    "FileView.computerIcon",
    "FileView.directoryIcon",
    "FileView.fileIcon",
    "FileView.floppyDriveIcon",
    "FileView.hardDriveIcon",
    "Focus.activeErrorBorderColor",
    "Focus.activeWarningBorderColor",
    "Focus.borderColor",
    "Focus.color",
    "Focus.defaultButtonBorderColor",
    "Focus.inactiveErrorBorderColor",
    "Focus.inactiveWarningBorderColor",
    "FormView.browseFileButton.textAndMnemonic",
    "FormView.resetButton.textAndMnemonic",
    "FormView.submitButton.textAndMnemonic",
    "FormattedTextField.background",
    "FormattedTextField.border",
    "FormattedTextField.caretBlinkRate",
    "FormattedTextField.caretForeground",
    "FormattedTextField.focusInputMap",
    "FormattedTextField.font",
    "FormattedTextField.foreground",
    "FormattedTextField.inactiveBackground",
    "FormattedTextField.inactiveForeground",
    "FormattedTextField.margin",
    "FormattedTextField.selectionBackground",
    "FormattedTextField.selectionForeground",
    "FormattedTextFieldUI",
    "Group.separatorColor",
    "HelpTooltip.backgroundColor",
    "HelpTooltip.borderColor",
    "HelpTooltip.defaultTextBorderInsets",
    "HelpTooltip.fontSizeDelta",
    "HelpTooltip.horizontalGap",
    "HelpTooltip.maxWidth",
    "HelpTooltip.shortcutTextColor",
    "HelpTooltip.smallTextBorderInsets",
    "HelpTooltip.textColor",
    "HelpTooltip.verticalGap",
    "HelpTooltip.xOffset",
    "HelpTooltip.yOffset",
    "Hyperlink.linkColor",
    "IconButton.font",
    "InsetBorder.aquaVariant",
    "InternalFrame.activeTitleBackground",
    "InternalFrame.activeTitleForeground",
    "InternalFrame.activeTitleGradient",
    "InternalFrame.background",
    "InternalFrame.border",
    "InternalFrame.borderColor",
    "InternalFrame.borderDarkShadow",
    "InternalFrame.borderHighlight",
    "InternalFrame.borderLight",
    "InternalFrame.borderShadow",
    "InternalFrame.closeButtonToolTip",
    "InternalFrame.closeIcon",
    "InternalFrame.closeSound",
    "InternalFrame.icon",
    "InternalFrame.iconButtonToolTip",
    "InternalFrame.iconifyIcon",
    "InternalFrame.inactiveTitleBackground",
    "InternalFrame.inactiveTitleForeground",
    "InternalFrame.maxButtonToolTip",
    "InternalFrame.maximizeIcon",
    "InternalFrame.maximizeSound",
    "InternalFrame.minimizeIcon",
    "InternalFrame.minimizeSound",
    "InternalFrame.opaque",
    "InternalFrame.optionDialogBackground",
    "InternalFrame.optionDialogBorder",
    "InternalFrame.optionDialogTitleFont",
    "InternalFrame.paletteBackground",
    "InternalFrame.paletteBorder",
    "InternalFrame.paletteCloseIcon",
    "InternalFrame.paletteTitleFont",
    "InternalFrame.paletteTitleHeight",
    "InternalFrame.restoreButtonToolTip",
    "InternalFrame.restoreDownSound",
    "InternalFrame.restoreUpSound",
    "InternalFrame.titleFont",
    "InternalFrame.windowBindings",
    "InternalFrameTitlePane.closeButton.textAndMnemonic",
    "InternalFrameTitlePane.closeButtonAccessibleName",
    "InternalFrameTitlePane.closeButtonOpacity",
    "InternalFrameTitlePane.iconifyButtonAccessibleName",
    "InternalFrameTitlePane.iconifyButtonOpacity",
    "InternalFrameTitlePane.maximizeButton.textAndMnemonic",
    "InternalFrameTitlePane.maximizeButtonAccessibleName",
    "InternalFrameTitlePane.maximizeButtonOpacity",
    "InternalFrameTitlePane.minimizeButton.textAndMnemonic",
    "InternalFrameTitlePane.moveButton.textAndMnemonic",
    "InternalFrameTitlePane.restoreButton.textAndMnemonic",
    "InternalFrameTitlePane.sizeButton.textAndMnemonic",
    "InternalFrameUI",
    "IsindexView.prompt",
    "Label.actionMap",
    "Label.background",
    "Label.disabledForeground",
    "Label.disabledShadow",
    "Label.font",
    "Label.foreground",
    "Label.opaque",
    "Label.selectedDisabledForeground",
    "Label.selectedForeground",
    "LabelUI",
    "List.actionMap",
    "List.background",
    "List.cellRenderer",
    "List.dropCellBackground",
    "List.dropLineColor",
    "List.evenRowBackgroundPainter",
    "List.focusCellHighlightBorder",
    "List.focusInputMap",
    "List.focusInputMap.RightToLeft",
    "List.font",
    "List.foreground",
    "List.noFocusBorder",
    "List.oddRowBackgroundPainter",
    "List.selectionBackground",
    "List.selectionForeground",
    "List.selectionInactiveBackground",
    "List.selectionInactiveForeground",
    "List.sourceListBackgroundPainter",
    "List.sourceListFocusedSelectionBackgroundPainter",
    "List.sourceListSelectionBackgroundPainter",
    "List.timeFactor",
    "ListUI",
    "Menu.acceleratorFont",
    "Menu.acceleratorForeground",
    "Menu.acceleratorSelectionForeground",
    "Menu.actionMap",
    "Menu.arrowIcon",
    "Menu.background",
    "Menu.border",
    "Menu.borderColor",
    "Menu.borderPainted",
    "Menu.cancelMode",
    "Menu.checkIcon",
    "Menu.consumesTabs",
    "Menu.crossMenuMnemonic",
    "Menu.disabledArrowIcon",
    "Menu.disabledBackground",
    "Menu.disabledForeground",
    "Menu.font",
    "Menu.foreground",
    "Menu.invertedArrowIcon",
    "Menu.margin",
    "Menu.maxGutterIconWidth",
    "Menu.menuPopupOffsetX",
    "Menu.menuPopupOffsetY",
    "Menu.opaque",
    "Menu.preserveTopLevelSelection",
    "Menu.selectionBackground",
    "Menu.selectionForeground",
    "Menu.separatorColor",
    "Menu.shortcutKeys",
    "Menu.submenuPopupOffsetX",
    "Menu.submenuPopupOffsetY",
    "MenuBar.actionMap",
    "MenuBar.background",
    "MenuBar.backgroundPainter",
    "MenuBar.border",
    "MenuBar.borderColor",
    "MenuBar.darcula.borderColor",
    "MenuBar.darcula.borderShadowColor",
    "MenuBar.disabledBackground",
    "MenuBar.disabledForeground",
    "MenuBar.font",
    "MenuBar.foreground",
    "MenuBar.gradient",
    "MenuBar.highlight",
    "MenuBar.margin",
    "MenuBar.selectedBackgroundPainter",
    "MenuBar.selectionBackground",
    "MenuBar.selectionForeground",
    "MenuBar.shadow",
    "MenuBar.windowBindings",
    "MenuBarUI",
    "MenuItem.acceleratorDelimiter",
    "MenuItem.acceleratorFont",
    "MenuItem.acceleratorForeground",
    "MenuItem.acceleratorSelectionForeground",
    "MenuItem.actionMap",
    "MenuItem.arrowIcon",
    "MenuItem.background",
    "MenuItem.border",
    "MenuItem.borderPainted",
    "MenuItem.checkIcon",
    "MenuItem.commandSound",
    "MenuItem.disabledBackground",
    "MenuItem.disabledForeground",
    "MenuItem.font",
    "MenuItem.foreground",
    "MenuItem.margin",
    "MenuItem.maxGutterIconWidth",
    "MenuItem.selectedBackgroundPainter",
    "MenuItem.selectionBackground",
    "MenuItem.selectionForeground",
    "MenuItemUI",
    "MenuUI",
    "NavBar.borderColor",
    "OnOffButtonUI",
    "OnePixelDivider.background",
    "OptionButtonUI",
    "OptionPane.background",
    "OptionPane.border",
    "OptionPane.buttonAreaBorder",
    "OptionPane.buttonClickThreshhold",
    "OptionPane.buttonFont",
    "OptionPane.cancelButton.textAndMnemonic",
    "OptionPane.cancelButtonMnemonic",
    "OptionPane.errorDialog.border.background",
    "OptionPane.errorDialog.titlePane.background",
    "OptionPane.errorDialog.titlePane.foreground",
    "OptionPane.errorDialog.titlePane.shadow",
    "OptionPane.errorIcon",
    "OptionPane.errorSound",
    "OptionPane.font",
    "OptionPane.foreground",
    "OptionPane.informationIcon",
    "OptionPane.informationSound",
    "OptionPane.inputDialog.titleAndMnemonic",
    "OptionPane.messageAreaBorder",
    "OptionPane.messageDialog.titleAndMnemonic",
    "OptionPane.messageFont",
    "OptionPane.messageForeground",
    "OptionPane.minimumSize",
    "OptionPane.noButton.textAndMnemonic",
    "OptionPane.noButtonMnemonic",
    "OptionPane.okButton.textAndMnemonic",
    "OptionPane.okButtonMnemonic",
    "OptionPane.questionDialog.border.background",
    "OptionPane.questionDialog.titlePane.background",
    "OptionPane.questionDialog.titlePane.foreground",
    "OptionPane.questionDialog.titlePane.shadow",
    "OptionPane.questionIcon",
    "OptionPane.questionSound",
    "OptionPane.title.textAndMnemonic",
    "OptionPane.warningDialog.border.background",
    "OptionPane.warningDialog.titlePane.background",
    "OptionPane.warningDialog.titlePane.foreground",
    "OptionPane.warningDialog.titlePane.shadow",
    "OptionPane.warningIcon",
    "OptionPane.warningSound",
    "OptionPane.windowBindings",
    "OptionPane.yesButton.textAndMnemonic",
    "OptionPane.yesButtonMnemonic",
    "OptionPaneUI",
    "Outline.color",
    "Outline.disabledColor",
    "Outline.focusedColor",
    "Panel.background",
    "Panel.font",
    "Panel.foreground",
    "Panel.opaque",
    "PanelUI",
    "PasswordField.background",
    "PasswordField.border",
    "PasswordField.capsLockIconColor",
    "PasswordField.caretBlinkRate",
    "PasswordField.caretForeground",
    "PasswordField.echoChar",
    "PasswordField.focusInputMap",
    "PasswordField.font",
    "PasswordField.foreground",
    "PasswordField.inactiveBackground",
    "PasswordField.inactiveForeground",
    "PasswordField.margin",
    "PasswordField.selectionBackground",
    "PasswordField.selectionForeground",
    "PasswordFieldUI",
    "Popup.Border.color",
    "Popup.Border.inactiveColor",
    "Popup.Header.activeBackground",
    "Popup.Header.inactiveBackground",
    "Popup.Toolbar.Border.color",
    "Popup.Toolbar.background",
    "PopupMenu.actionMap",
    "PopupMenu.background",
    "PopupMenu.border",
    "PopupMenu.consumeEventOnClose",
    "PopupMenu.font",
    "PopupMenu.foreground",
    "PopupMenu.popupSound",
    "PopupMenu.selectedWindowInputMapBindings",
    "PopupMenu.selectedWindowInputMapBindings.RightToLeft",
    "PopupMenu.selectionBackground",
    "PopupMenu.selectionForeground",
    "PopupMenu.translucentBackground",
    "PopupMenuSeparatorUI",
    "PopupMenuUI",
    "PrintingDialog.abortButton.textAndMnemonic",
    "PrintingDialog.abortButtonToolTip.textAndMnemonic",
    "PrintingDialog.contentAborting.textAndMnemonic",
    "PrintingDialog.contentInitial.textAndMnemonic",
    "PrintingDialog.contentProgress.textAndMnemonic",
    "PrintingDialog.titleAborting.textAndMnemonic",
    "PrintingDialog.titleProgress.textAndMnemonic",
    "ProgressBar.background",
    "ProgressBar.border",
    "ProgressBar.cellLength",
    "ProgressBar.cellSpacing",
    "ProgressBar.cycleTime",
    "ProgressBar.failedColor",
    "ProgressBar.failedEndColor",
    "ProgressBar.font",
    "ProgressBar.foreground",
    "ProgressBar.horizontalSize",
    "ProgressBar.indeterminateEndColor",
    "ProgressBar.indeterminateStartColor",
    "ProgressBar.passedColor",
    "ProgressBar.passedEndColor",
    "ProgressBar.progressColor",
    "ProgressBar.repaintInterval",
    "ProgressBar.selectionBackground",
    "ProgressBar.selectionForeground",
    "ProgressBar.trackColor",
    "ProgressBar.verticalSize",
    "ProgressBarUI",
    "ProgressMonitor.progress.textAndMnemonic",
    "RadioButton.background",
    "RadioButton.border",
    "RadioButton.borderInsets",
    "RadioButton.darcula.selectionDisabledColor",
    "RadioButton.darcula.selectionDisabledShadowColor",
    "RadioButton.darcula.selectionEnabledColor",
    "RadioButton.darcula.selectionEnabledShadowColor",
    "RadioButton.darkShadow",
    "RadioButton.disabledText",
    "RadioButton.focus",
    "RadioButton.focusInputMap",
    "RadioButton.font",
    "RadioButton.foreground",
    "RadioButton.gradient",
    "RadioButton.highlight",
    "RadioButton.icon",
    "RadioButton.light",
    "RadioButton.margin",
    "RadioButton.rollover",
    "RadioButton.select",
    "RadioButton.shadow",
    "RadioButton.textIconGap",
    "RadioButton.textShiftOffset",
    "RadioButton.totalInsets",
    "RadioButtonMenuItem.acceleratorDelimiter",
    "RadioButtonMenuItem.acceleratorFont",
    "RadioButtonMenuItem.acceleratorForeground",
    "RadioButtonMenuItem.acceleratorSelectionForeground",
    "RadioButtonMenuItem.arrowIcon",
    "RadioButtonMenuItem.background",
    "RadioButtonMenuItem.border",
    "RadioButtonMenuItem.borderPainted",
    "RadioButtonMenuItem.checkIcon",
    "RadioButtonMenuItem.commandSound",
    "RadioButtonMenuItem.dashIcon",
    "RadioButtonMenuItem.disabledBackground",
    "RadioButtonMenuItem.disabledForeground",
    "RadioButtonMenuItem.font",
    "RadioButtonMenuItem.foreground",
    "RadioButtonMenuItem.gradient",
    "RadioButtonMenuItem.margin",
    "RadioButtonMenuItem.selectionBackground",
    "RadioButtonMenuItem.selectionForeground",
    "RadioButtonMenuItemUI",
    "RadioButtonUI",
    "RootPane.actionMap",
    "RootPane.ancestorInputMap",
    "RootPane.colorChooserDialogBorder",
    "RootPane.defaultButtonWindowKeyBindings",
    "RootPane.errorDialogBorder",
    "RootPane.fileChooserDialogBorder",
    "RootPane.frameBorder",
    "RootPane.informationDialogBorder",
    "RootPane.plainDialogBorder",
    "RootPane.questionDialogBorder",
    "RootPane.warningDialogBorder",
    "RootPaneUI",
    "ScrollBar.actionMap",
    "ScrollBar.allowsAbsolutePositioning",
    "ScrollBar.ancestorInputMap",
    "ScrollBar.ancestorInputMap.RightToLeft",
    "ScrollBar.background",
    "ScrollBar.darkShadow",
    "ScrollBar.decrementButtonGap",
    "ScrollBar.focusInputMap",
    "ScrollBar.focusInputMap.RightToLeft",
    "ScrollBar.foreground",
    "ScrollBar.gradient",
    "ScrollBar.highlight",
    "ScrollBar.incrementButtonGap",
    "ScrollBar.maximumThumbSize",
    "ScrollBar.minimumThumbSize",
    "ScrollBar.shadow",
    "ScrollBar.thumb",
    "ScrollBar.thumbDarkShadow",
    "ScrollBar.thumbHighlight",
    "ScrollBar.thumbShadow",
    "ScrollBar.track",
    "ScrollBar.trackHighlight",
    "ScrollBar.width",
    "ScrollBarUI",
    "ScrollPane.actionMap",
    "ScrollPane.ancestorInputMap",
    "ScrollPane.ancestorInputMap.RightToLeft",
    "ScrollPane.background",
    "ScrollPane.border",
    "ScrollPane.font",
    "ScrollPane.foreground",
    "ScrollPaneUI",
    "SearchEverywhere.Header.background",
    "SearchEverywhere.List.Separator.Color",
    "SearchEverywhere.SearchField.borderColor",
    "SearchEverywhere.SearchField.background",
    "SearchEverywhere.Tab.active.background",
    "SearchEverywhere.Tab.active.foreground",
    "SearchEverywhere.SearchField.grayForeground",
    "SearchEverywhere.Advertiser.foreground",
    "SearchEverywhere.Advertiser.background",
    "SearchEverywhere.background",
    "SearchEverywhere.foreground",
    "SearchEverywhere.shortcutForeground",
    "Separator.background",
    "Separator.foreground",
    "Separator.highlight",
    "Separator.shadow",
    "SeparatorUI",
    "Slider.actionMap",
    "Slider.altTrackColor",
    "Slider.background",
    "Slider.disabledForeground",
    "Slider.focus",
    "Slider.focusGradient",
    "Slider.focusInputMap",
    "Slider.focusInputMap.RightToLeft",
    "Slider.focusInsets",
    "Slider.focusedColor",
    "Slider.font",
    "Slider.foreground",
    "Slider.gradient",
    "Slider.highlight",
    "Slider.horizontalSize",
    "Slider.horizontalThumbIcon",
    "Slider.majorTickLength",
    "Slider.minimumHorizontalSize",
    "Slider.minimumVerticalSize",
    "Slider.onlyLeftMouseButtonDrag",
    "Slider.pressedColor",
    "Slider.shadow",
    "Slider.tickColor",
    "Slider.trackWidth",
    "Slider.verticalSize",
    "Slider.verticalThumbIcon",
    "SliderUI",
    "Spinner.actionMap",
    "Spinner.ancestorInputMap",
    "Spinner.arrowButtonInsets",
    "Spinner.arrowButtonSize",
    "Spinner.background",
    "Spinner.border",
    "Spinner.darcula.disabledButtonColor",
    "Spinner.darcula.enabledButtonColor",
    "Spinner.editorAlignment",
    "Spinner.editorBorderPainted",
    "Spinner.font",
    "Spinner.foreground",
    "SpinnerUI",
    "SplitPane.ancestorInputMap",
    "SplitPane.background",
    "SplitPane.border",
    "SplitPane.centerOneTouchButtons",
    "SplitPane.darkShadow",
    "SplitPane.dividerFocusColor",
    "SplitPane.dividerSize",
    "SplitPane.highlight",
    "SplitPane.leftButton.textAndMnemonic",
    "SplitPane.oneTouchButtonsOpaque",
    "SplitPane.rightButton.textAndMnemonic",
    "SplitPane.shadow",
    "SplitPaneDivider.border",
    "SplitPaneDivider.draggingColor",
    "SplitPaneDivider.horizontalGradientVariant",
    "SplitPaneUI",
    "StatusBar.borderColor",
    "StatusBar.bottomColor",
    "StatusBar.top2Color",
    "StatusBar.topColor",
    "StyledEditorKit.JBDefaultStyle",
    "TabbedPane.actionMap",
    "TabbedPane.ancestorInputMap",
    "TabbedPane.background",
    "TabbedPane.borderHightlightColor",
    "TabbedPane.contentAreaColor",
    "TabbedPane.contentBorderInsets",
    "TabbedPane.contentOpaque",
    "TabbedPane.darkShadow",
    "TabbedPane.disabledText",
    "TabbedPane.focus",
    "TabbedPane.focusColor",
    "TabbedPane.focusInputMap",
    "TabbedPane.font",
    "TabbedPane.foreground",
    "TabbedPane.highlight",
    "TabbedPane.hoverColor",
    "TabbedPane.labelShift",
    "TabbedPane.leftTabInsets",
    "TabbedPane.light",
    "TabbedPane.nonSelectedTabTitleNormalColor",
    "TabbedPane.opaque",
    "TabbedPane.rightTabInsets",
    "TabbedPane.selectHighlight",
    "TabbedPane.selected",
    "TabbedPane.selectedColor",
    "TabbedPane.selectedDisabledColor",
    "TabbedPane.selectedLabelShift",
    "TabbedPane.selectedTabPadInsets",
    "TabbedPane.selectedTabTitleDisabledColor",
    "TabbedPane.selectedTabTitleNormalColor",
    "TabbedPane.selectedTabTitlePressedColor",
    "TabbedPane.selectedTabTitleShadowDisabledColor",
    "TabbedPane.selectedTabTitleShadowNormalColor",
    "TabbedPane.selectionFollowsFocus",
    "TabbedPane.shadow",
    "TabbedPane.smallFont",
    "TabbedPane.tabAreaBackground",
    "TabbedPane.tabAreaInsets",
    "TabbedPane.tabFillStyle",
    "TabbedPane.tabHeight",
    "TabbedPane.tabInsets",
    "TabbedPane.tabRunOverlay",
    "TabbedPane.tabSelectionHeight",
    "TabbedPane.tabsOpaque",
    "TabbedPane.tabsOverlapBorder",
    "TabbedPane.textIconGap",
    "TabbedPane.unselectedBackground",
    "TabbedPane.useSmallLayout",
    "TabbedPaneUI",
    "Table.actionMap",
    "Table.ancestorInputMap",
    "Table.ancestorInputMap.RightToLeft",
    "Table.ascendingSortIcon",
    "Table.background",
    "Table.cellNoFocusBorder",
    "Table.descendingSortIcon",
    "Table.dropCellBackground",
    "Table.dropLineColor",
    "Table.dropLineShortColor",
    "Table.focusCellBackground",
    "Table.focusCellForeground",
    "Table.focusCellHighlightBorder",
    "Table.focusSelectedCellHighlightBorder",
    "Table.font",
    "Table.foreground",
    "Table.gridColor",
    "Table.scrollPaneBorder",
    "Table.selectionBackground",
    "Table.selectionForeground",
    "Table.selectionInactiveBackground",
    "Table.selectionInactiveForeground",
    "Table.sortIconColor",
    "TableHeader.actionMap",
    "TableHeader.ancestorInputMap",
    "TableHeader.background",
    "TableHeader.cellBorder",
    "TableHeader.focusCellBackground",
    "TableHeader.font",
    "TableHeader.foreground",
    "TableHeaderUI",
    "TableUI",
    "TextArea.actionMap",
    "TextArea.background",
    "TextArea.border",
    "TextArea.caretBlinkRate",
    "TextArea.caretForeground",
    "TextArea.focusInputMap",
    "TextArea.font",
    "TextArea.foreground",
    "TextArea.inactiveBackground",
    "TextArea.inactiveForeground",
    "TextArea.margin",
    "TextArea.selectionBackground",
    "TextArea.selectionForeground",
    "TextAreaUI",
    "TextComponent.selectionBackgroundInactive",
    "TextField.actionMap",
    "TextField.background",
    "TextField.border",
    "TextField.borderColor",
    "TextField.caretBlinkRate",
    "TextField.caretForeground",
    "TextField.darcula.clear.icon",
    "TextField.darcula.search.icon",
    "TextField.darcula.searchWithHistory.icon",
    "TextField.darkShadow",
    "TextField.disabledBackground",
    "TextField.focusInputMap",
    "TextField.focusedBorderColor",
    "TextField.font",
    "TextField.foreground",
    "TextField.highlight",
    "TextField.hoverBorderColor",
    "TextField.inactiveBackground",
    "TextField.inactiveForeground",
    "TextField.light",
    "TextField.margin",
    "TextField.selectionBackground",
    "TextField.selectionForeground",
    "TextField.shadow",
    "TextFieldUI",
    "TextPane.background",
    "TextPane.border",
    "TextPane.caretBlinkRate",
    "TextPane.caretForeground",
    "TextPane.focusInputMap",
    "TextPane.font",
    "TextPane.foreground",
    "TextPane.inactiveBackground",
    "TextPane.inactiveForeground",
    "TextPane.margin",
    "TextPane.selectionBackground",
    "TextPane.selectionForeground",
    "TextPaneUI",
    "TitledBorder.aquaVariant",
    "TitledBorder.border",
    "TitledBorder.font",
    "TitledBorder.titleColor",
    "ToggleButton.background",
    "ToggleButton.border",
    "ToggleButton.darkShadow",
    "ToggleButton.disabledText",
    "ToggleButton.focus",
    "ToggleButton.focusInputMap",
    "ToggleButton.font",
    "ToggleButton.foreground",
    "ToggleButton.gradient",
    "ToggleButton.highlight",
    "ToggleButton.light",
    "ToggleButton.margin",
    "ToggleButton.select",
    "ToggleButton.shadow",
    "ToggleButton.textIconGap",
    "ToggleButton.textShiftOffset",
    "ToggleButtonUI",
    "ToolBar.ancestorInputMap",
    "ToolBar.background",
    "ToolBar.border",
    "ToolBar.borderColor",
    "ToolBar.borderHandleColor",
    "ToolBar.darkShadow",
    "ToolBar.dockingBackground",
    "ToolBar.dockingForeground",
    "ToolBar.floatingBackground",
    "ToolBar.floatingForeground",
    "ToolBar.font",
    "ToolBar.foreground",
    "ToolBar.highlight",
    "ToolBar.isRollover",
    "ToolBar.light",
    "ToolBar.nonrolloverBorder",
    "ToolBar.rolloverBorder",
    "ToolBar.separatorSize",
    "ToolBar.shadow",
    "ToolBarButton.insets",
    "ToolBarButton.margin",
    "ToolBarSeparatorUI",
    "ToolBarUI",
    "ToolTip.background",
    "ToolTip.backgroundInactive",
    "ToolTip.border",
    "ToolTip.borderInactive",
    "ToolTip.font",
    "ToolTip.foreground",
    "ToolTip.foregroundInactive",
    "ToolTip.hideAccelerator",
    "ToolTipManager.enableToolTipMode",
    "ToolTipUI",
    "ToolWindow.header.active.background",
    "ToolWindow.header.background",
    "ToolWindow.header.border.background",
    "ToolWindow.header.closeButton.background",
    "ToolWindow.header.font.size",
    "ToolWindow.header.tab.selected.active.background",
    "ToolWindow.header.tab.selected.background",
    "ToolWindow.overridden.header.font.size.offset",
    "Tree.actionMap",
    "Tree.background",
    "Tree.changeSelectionWithFocus",
    "Tree.closedIcon",
    "Tree.collapsedIcon",
    "Tree.drawsFocusBorderAroundIcon",
    "Tree.dropCellBackground",
    "Tree.dropLineColor",
    "Tree.editorBorder",
    "Tree.expandedIcon",
    "Tree.focusInputMap",
    "Tree.focusInputMap.RightToLeft",
    "Tree.font",
    "Tree.foreground",
    "Tree.hash",
    "Tree.leafIcon",
    "Tree.leftChildIndent",
    "Tree.line",
    "Tree.lineTypeDashed",
    "Tree.openIcon",
    "Tree.paintLines",
    "Tree.repaintWholeRow",
    "Tree.rightChildIndent",
    "Tree.rightToLeftCollapsedIcon",
    "Tree.rowHeight",
    "Tree.scrollsOnExpand",
    "Tree.selectionBackground",
    "Tree.selectionBorderColor",
    "Tree.selectionForeground",
    "Tree.selectionInactiveBackground",
    "Tree.selectionInactiveForeground",
    "Tree.textBackground",
    "Tree.textForeground",
    "Tree.timeFactor",
    "TreeUI",
    "ValidationTooltip.errorBackgroundColor",
    "ValidationTooltip.errorBorderColor",
    "ValidationTooltip.maxWidth",
    "ValidationTooltip.warningBackgroundColor",
    "ValidationTooltip.warningBorderColor",
    "Viewport.background",
    "Viewport.font",
    "Viewport.foreground",
    "ViewportUI",
    "_SecurityDecisionIcon",
    "activeCaption",
    "activeCaptionBorder",
    "activeCaptionText",
    "class com.apple.laf.AquaLabelUI",
    "class com.apple.laf.AquaListUI",
    "class com.apple.laf.AquaMenuBarUI",
    "class com.apple.laf.AquaPanelUI",
    "class com.apple.laf.AquaPopupMenuSeparatorUI",
    "class com.apple.laf.AquaPopupMenuUI",
    "class com.apple.laf.AquaRootPaneUI",
    "class com.apple.laf.AquaScrollPaneUI",
    "class com.apple.laf.AquaTableUI",
    "class com.intellij.ide.ui.laf.darcula.DarculaTableHeaderUI",
    "class com.intellij.ide.ui.laf.darcula.ui.DarculaButtonUI",
    "class com.intellij.ide.ui.laf.darcula.ui.DarculaCheckBoxUI",
    "class com.intellij.ide.ui.laf.darcula.ui.DarculaComboBoxUI",
    "class com.intellij.ide.ui.laf.darcula.ui.DarculaEditorPaneUI",
    "class com.intellij.ide.ui.laf.darcula.ui.DarculaProgressBarUI",
    "class com.intellij.ide.ui.laf.darcula.ui.DarculaRadioButtonUI",
    "class com.intellij.ide.ui.laf.darcula.ui.DarculaRootPaneUI",
    "class com.intellij.ide.ui.laf.darcula.ui.DarculaSeparatorUI",
    "class com.intellij.ide.ui.laf.darcula.ui.DarculaSpinnerUI",
    "class com.intellij.ide.ui.laf.darcula.ui.DarculaTabbedPaneUI",
    "class com.intellij.ide.ui.laf.darcula.ui.DarculaTextAreaUI",
    "class com.intellij.ide.ui.laf.darcula.ui.DarculaTextFieldUI",
    "class com.intellij.ide.ui.laf.darcula.ui.DarculaTreeUI",
    "class com.intellij.ide.ui.laf.intellij.IntelliJCheckBoxUI",
    "class com.intellij.ide.ui.laf.intellij.MacIntelliJButtonUI",
    "class com.intellij.ide.ui.laf.intellij.MacIntelliJCheckBoxUI",
    "class com.intellij.ide.ui.laf.intellij.MacIntelliJComboBoxUI",
    "class com.intellij.ide.ui.laf.intellij.MacIntelliJProgressBarUI",
    "class com.intellij.ide.ui.laf.intellij.MacIntelliJRadioButtonUI",
    "class com.intellij.ide.ui.laf.intellij.MacIntelliJSpinnerUI",
    "class com.intellij.ide.ui.laf.intellij.MacIntelliJTextFieldUI",
    "class com.intellij.ide.ui.laf.intellij.WinIntelliJButtonUI",
    "class com.intellij.ide.ui.laf.intellij.WinIntelliJCheckBoxUI",
    "class com.intellij.ui.components.JBScrollBar",
    "class com.intellij.ui.mac.MacPopupMenuUI",
    "class com.intellij.ui.plaf.beg.BegTableUI",
    "class com.sun.java.swing.plaf.windows.WindowsLabelUI",
    "class com.sun.java.swing.plaf.windows.WindowsRootPaneUI",
    "class javax.swing.plaf.basic.BasicListUI",
    "class javax.swing.plaf.basic.BasicMenuBarUI",
    "class javax.swing.plaf.basic.BasicMenuItemUI",
    "class javax.swing.plaf.basic.BasicPanelUI",
    "class javax.swing.plaf.basic.BasicPopupMenuUI",
    "class javax.swing.plaf.basic.BasicTextPaneUI",
    "class javax.swing.plaf.basic.BasicViewportUI",
    "class javax.swing.plaf.metal.MetalLabelUI",
    "class javax.swing.plaf.metal.MetalRootPaneUI",
    "class javax.swing.plaf.metal.MetalScrollPaneUI",
    "class javax.swing.plaf.metal.MetalSeparatorUI",
    "class javax.swing.plaf.metal.MetalSliderUI",
    "class javax.swing.plaf.synth.SynthLookAndFeel",
    "com.apple.laf.AquaLabelUI",
    "com.apple.laf.AquaListUI",
    "com.apple.laf.AquaMenuBarUI",
    "com.apple.laf.AquaPanelUI",
    "com.apple.laf.AquaPopupMenuSeparatorUI",
    "com.apple.laf.AquaPopupMenuUI",
    "com.apple.laf.AquaRootPaneUI",
    "com.apple.laf.AquaScrollPaneUI",
    "com.apple.laf.AquaTableUI",
    "com.intellij.ide.ui.laf.darcula.DarculaTableHeaderUI",
    "com.intellij.ide.ui.laf.darcula.ui.DarculaButtonUI",
    "com.intellij.ide.ui.laf.darcula.ui.DarculaCheckBoxUI",
    "com.intellij.ide.ui.laf.darcula.ui.DarculaComboBoxUI",
    "com.intellij.ide.ui.laf.darcula.ui.DarculaEditorPaneUI",
    "com.intellij.ide.ui.laf.darcula.ui.DarculaProgressBarUI",
    "com.intellij.ide.ui.laf.darcula.ui.DarculaRadioButtonUI",
    "com.intellij.ide.ui.laf.darcula.ui.DarculaRootPaneUI",
    "com.intellij.ide.ui.laf.darcula.ui.DarculaSeparatorUI",
    "com.intellij.ide.ui.laf.darcula.ui.DarculaSpinnerUI",
    "com.intellij.ide.ui.laf.darcula.ui.DarculaTabbedPaneUI",
    "com.intellij.ide.ui.laf.darcula.ui.DarculaTextAreaUI",
    "com.intellij.ide.ui.laf.darcula.ui.DarculaTextFieldUI",
    "com.intellij.ide.ui.laf.darcula.ui.DarculaTreeUI",
    "com.intellij.ide.ui.laf.intellij.IntelliJCheckBoxUI",
    "com.intellij.ide.ui.laf.intellij.MacIntelliJButtonUI",
    "com.intellij.ide.ui.laf.intellij.MacIntelliJCheckBoxUI",
    "com.intellij.ide.ui.laf.intellij.MacIntelliJComboBoxUI",
    "com.intellij.ide.ui.laf.intellij.MacIntelliJProgressBarUI",
    "com.intellij.ide.ui.laf.intellij.MacIntelliJRadioButtonUI",
    "com.intellij.ide.ui.laf.intellij.MacIntelliJSpinnerUI",
    "com.intellij.ide.ui.laf.intellij.MacIntelliJTextFieldUI",
    "com.intellij.ide.ui.laf.intellij.WinIntelliJButtonUI",
    "com.intellij.ide.ui.laf.intellij.WinIntelliJCheckBoxUI",
    "com.intellij.ui.components.JBScrollBar",
    "com.intellij.ui.mac.MacPopupMenuUI",
    "com.intellij.ui.plaf.beg.BegTableUI",
    "com.sun.java.swing.plaf.windows.WindowsLabelUI",
    "com.sun.java.swing.plaf.windows.WindowsRootPaneUI",
    "control",
    "controlDkShadow",
    "controlHighlight",
    "controlLtHighlight",
    "controlShadow",
    "controlText",
    "darcula.background",
    "darcula.caretForeground",
    "darcula.foreground",
    "darcula.inactiveBackground",
    "darcula.selectionBackground",
    "darcula.selectionBackgroundInactive",
    "darcula.selectionForeground",
    "darcula.selectionForegroundInactive",
    "darcula.selectionInactiveBackground",
    "darcula.selectionInactiveForeground",
    "darcula.textBackground",
    "darcula.textForeground",
    "desktop",
    "grayFilter",
    "hidpi.scaleFactor",
    "html.missingImage",
    "html.pendingImage",
    "inactiveCaption",
    "inactiveCaptionBorder",
    "inactiveCaptionText",
    "info",
    "infoText",
    "intellijlaf.background",
    "intellijlaf.caretForeground",
    "intellijlaf.foreground",
    "intellijlaf.inactiveBackground",
    "intellijlaf.inactiveForeground",
    "intellijlaf.selectionBackground",
    "intellijlaf.selectionBackgroundInactive",
    "intellijlaf.selectionForeground",
    "intellijlaf.selectionForegroundInactive",
    "intellijlaf.selectionInactiveBackground",
    "intellijlaf.textBackground",
    "intellijlaf.textForeground",
    "intellijlaf_native.acceleratorSelectionForeground",
    "intellijlaf_native.background",
    "intellijlaf_native.caretForeground",
    "intellijlaf_native.disabledForeground",
    "intellijlaf_native.foreground",
    "intellijlaf_native.inactiveBackground",
    "intellijlaf_native.inactiveForeground",
    "intellijlaf_native.selectionBackground",
    "intellijlaf_native.selectionBackgroundInactive",
    "intellijlaf_native.selectionForeground",
    "intellijlaf_native.selectionForegroundInactive",
    "intellijlaf_native.selectionInactiveBackground",
    "intellijlaf_native.textBackground",
    "intellijlaf_native.textForeground",
    "javax.swing.JLabel.userStyleSheet",
    "javax.swing.plaf.basic.BasicListUI",
    "javax.swing.plaf.basic.BasicMenuBarUI",
    "javax.swing.plaf.basic.BasicMenuItemUI",
    "javax.swing.plaf.basic.BasicPanelUI",
    "javax.swing.plaf.basic.BasicPopupMenuUI",
    "javax.swing.plaf.basic.BasicTextPaneUI",
    "javax.swing.plaf.basic.BasicViewportUI",
    "javax.swing.plaf.metal.MetalLabelUI",
    "javax.swing.plaf.metal.MetalRootPaneUI",
    "javax.swing.plaf.metal.MetalScrollPaneUI",
    "javax.swing.plaf.metal.MetalSeparatorUI",
    "javax.swing.plaf.metal.MetalSliderUI",
    "javax.swing.plaf.synth.SynthLookAndFeel",
    "link.foreground",
    "link.hover.foreground",
    "link.pressed.foreground",
    "link.visited.foreground",
    "menu",
    "menuText",
    "scrollbar",
    "text",
    "text.grayFilter",
    "textHighlight",
    "textHighlightText",
    "textInactiveText",
    "textText",
    "window",
    "windowBorder",
    "windowText"
  );
}
