/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.jps.javac.ast;

import com.intellij.util.Consumer;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.jps.builders.java.JavaCompilingTool;
import org.jetbrains.jps.javac.DiagnosticOutputConsumer;
import org.jetbrains.jps.javac.JavaCompilerToolExtension;
import org.jetbrains.jps.javac.ast.api.JavacFileData;

import javax.tools.*;
import java.util.Collection;

public abstract class AbstractRefCollectorCompilerToolExtension extends JavaCompilerToolExtension {
  @Override
  public final void beforeCompileTaskExecution(@NotNull JavaCompilingTool compilingTool,
                                         @NotNull JavaCompiler.CompilationTask task,
                                         @NotNull Collection<String> options,
                                         @NotNull DiagnosticOutputConsumer diagnosticConsumer) {
    if (isEnabled()) {
      JavacReferenceCollector.installOn(task, divideImportsRefs(), getFileDataConsumer(diagnosticConsumer));
    }
  }

  protected abstract boolean isEnabled();

  protected abstract boolean divideImportsRefs();

  @NotNull
  protected abstract Consumer<JavacFileData> getFileDataConsumer(@NotNull DiagnosticOutputConsumer diagnosticConsumer);
}
