/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.plugins.groovy.ext.logback

import groovy.lang.Closure
import org.jetbrains.plugins.groovy.lang.psi.api.statements.blocks.GrClosableBlock
import org.jetbrains.plugins.groovy.lang.psi.impl.statements.expressions.TypesUtil
import org.jetbrains.plugins.groovy.lang.psi.patterns.groovyClosure
import org.jetbrains.plugins.groovy.lang.psi.patterns.psiMethod
import org.jetbrains.plugins.groovy.lang.resolve.delegatesTo.DelegatesToInfo
import org.jetbrains.plugins.groovy.lang.resolve.delegatesTo.GrDelegatesToProvider

class LogbackDelegatesToProvider : GrDelegatesToProvider {

  private companion object {
    val appenderDelegateFqn = "ch.qos.logback.classic.gaffer.AppenderDelegate"
    val appendClosure = groovyClosure().inMethod(appenderMethodPattern)
    val receiverClosure = groovyClosure().inMethod(psiMethod(configDelegateFqn, "receiver"))
    val turboFilterClosure = groovyClosure().inMethod(psiMethod(configDelegateFqn, "turboFilter"))
  }

  override fun getDelegatesToInfo(closure: GrClosableBlock): DelegatesToInfo? {
    if (appendClosure.accepts(closure)) {
      return DelegatesToInfo(TypesUtil.createType(appenderDelegateFqn, closure), Closure.DELEGATE_FIRST)
    }
    if (receiverClosure.accepts(closure) || turboFilterClosure.accepts(closure)) {
      return DelegatesToInfo(TypesUtil.createType(componentDelegateFqn, closure), Closure.DELEGATE_FIRST)
    }
    return null
  }
}