/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.plugins.terminal;

import com.intellij.openapi.Disposable;
import com.intellij.openapi.options.ConfigurationException;
import com.intellij.openapi.options.SearchableConfigurable;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.util.Disposer;
import org.jetbrains.annotations.Nls;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;

/**
 * @author traff
 */
public class TerminalOptionsConfigurable implements SearchableConfigurable, Disposable {
  public static final String TERMINAL_SETTINGS_HELP_REFERENCE = "reference.settings.terminal";

  private TerminalSettingsPanel myPanel;
  private final TerminalOptionsProvider myOptionsProvider;
  private final TerminalProjectOptionsProvider myProjectOptionsProvider;

  public TerminalOptionsConfigurable(@NotNull Project project) {
    myOptionsProvider = TerminalOptionsProvider.getInstance();
    myProjectOptionsProvider = TerminalProjectOptionsProvider.getInstance(project);
  }

  @NotNull
  @Override
  public String getId() {
    return "terminal";
  }

  @Nls
  @Override
  public String getDisplayName() {
    return "Terminal";
  }

  @Override
  public String getHelpTopic() {
    return TERMINAL_SETTINGS_HELP_REFERENCE;
  }

  @Override
  public JComponent createComponent() {
    myPanel = new TerminalSettingsPanel();
    return myPanel.createPanel(myOptionsProvider, myProjectOptionsProvider);
  }

  @Override
  public boolean isModified() {
    return myPanel.isModified();
  }

  @Override
  public void apply() throws ConfigurationException {
    myPanel.apply();
  }

  @Override
  public void reset() {
    myPanel.reset();
  }

  @Override
  public void disposeUIResources() {
    Disposer.dispose(this);
  }

  @Override
  public void dispose() {
    myPanel = null;
  }
}
